print("import: 'git'")
import git

print("import: 'git.index'")
import git.index

print("import: 'git.objects'")
import git.objects

print("import: 'git.objects.submodule'")
import git.objects.submodule

print("import: 'git.refs'")
import git.refs

print("import: 'git.repo'")
import git.repo

